Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Method ¶
type Method interface {
ProtoReflect
Name() string
FullName() string
ServicePolicy() ServicePolicy
CallPolicy() MethodCallPolicy
}
type MethodCallPolicy ¶
type ProtoReflect ¶
type ProtoReflect interface {
WasSet(*protoimpl.ExtensionInfo) bool
}
type Service ¶
type Service interface {
Name() string
ShortName() string
Db() pkg.Db
OpenDb() error
Configurator() ServiceConfigurator
WithConfigurator(ServiceConfigurator)
ReloadConfig(uint) error
FetchConfig(uint) (ServiceConfigurator, error)
Server() grpc.BaseServer
WithServer(grpc.BaseServer)
IpcServer() grpc.BaseServer
WithIpcServer(server grpc.BaseServer)
Policy() ServicePolicy
WithPolicy(ServicePolicy)
InitTask(j job.Job) (job.Init, job.Run, job.Finalize)
}
type ServiceConfigurator ¶
type ServiceConfigurator interface {
node.Configurator
Address() net.Addr
}
type ServiceGlobalOptions ¶
type ServiceGlobalOptions interface {
EnforceEncryption() bool
}
Options that can be specified both in service or method scope. Option value specified in a method scope will override the value specified in the service scope.
type ServiceOptionValue ¶
type ServiceOptionValue interface {
WasSet() bool
Value() interface{}
}
type ServicePolicy ¶
type ServicePolicy interface {
ProtoReflect
ServiceGlobalOptions
DefaultPort() uint16
Ipc_UnixDomainSocket() string
FindMethodByName(string) (Method, bool)
}
Click to show internal directories.
Click to hide internal directories.